..
    Copyright (C) 2019 CESNET.

    Invenio OpenID Connect is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

=======================
 Invenio OpenID Connect
=======================

.. image:: https://img.shields.io/github/license/oarepo/invenio-openid-connect.svg
        :target: https://github.com/oarepo/invenio-openid-connect/blob/master/LICENSE

.. image:: https://img.shields.io/travis/oarepo/invenio-openid-connect.svg
        :target: https://travis-ci.org/oarepo/invenio-openid-connect

.. image:: https://img.shields.io/coveralls/oarepo/oarepo-openid-connect.svg
        :target: https://coveralls.io/r/oarepo/invenio-openid-connect

.. image:: https://img.shields.io/pypi/v/invenio-openid-connect.svg
        :target: https://pypi.org/pypi/invenio-openid-connect

Invenio OpenID Connect Auth Backend

Further documentation is available on
https://invenio-openid-connect.readthedocs.io/

